% script that illustrates Kalman filter on a simple model;

% close all 
clear all
close all
clc

%% load and solve the model
m = model('closed_model.model','linear',true);
p = setparam;
m = assign(m,p);

m = solve(m);
m = sstate(m); 

%% Create multiple parameterizations if needed
 m = alter(m,2);
 
 m.c2_dl_cpi = [0.15 0.30];

 m = solve(m);
 m = sstate(m); 

ss = get(m,'sstate')

%% Run the IRFs



% run a loop over model shocks
shocks = get(m,'elist');


for iShock = 1:numel(shocks)
  % iterate over shocks

  % Create initial condition
  dbinit = zerodb(m,qq(2010,1):qq(2012,4));

  % find the name of this shock
  shk = shocks{iShock};
  
  % set the shock to non-zero value in the first period of simulation
  dbinit.(shk)(qq(2013,1)) = 1;
  
  % run the simulation
  s = simulate(m,dbinit,qq(2013,1):qq(2018,1),'deviation',true);
  s = dboverlay(s, dbinit);
  
  % make a picture showing the IRFs
  figure('Name',['IRF to ' shk]);
  subplot(221);
    plot(s.l_y_gap,'lineWidth',3);
    grid;
    title('Output gap (%)');
    legend('Model 1', 'Model 2');
  subplot(222);
    plot(s.dl_cpi,'lineWidth',3);
    grid;
    title('Inflation (%)');
  subplot(223);
    plot(s.r_gap,'lineWidth',3);
    grid;
    title('Real interest rate gap (pp)'); 
end



